==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/sound/translations/sound_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>@default</name>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Sound theme</source>
        <translation>Tema de sonido</translation>
    </message>
    <message>
        <source>Sound paths</source>
        <translation>Rutas de Sonidos</translation>
    </message>
    <message>
        <source>Test sound playing</source>
        <translation>Sonido de prueba</translation>
    </message>
    <message>
        <source>Play a sound</source>
        <translation>Reproducir un sonido</translation>
    </message>
    <message>
        <source>Enable sound notifications</source>
        <translation>Activar notificaciones de sonido</translation>
    </message>
</context>
<context>
    <name>SoundBuddyConfigurationWidget</name>
    <message>
        <source>Use custom sound</source>
        <translation>Usar sonido personalizado</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
</context>
<context>
    <name>SoundChatConfigurationWidget</name>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Use custom sound</source>
        <translation>Usar sonido personalizado</translation>
    </message>
</context>
<context>
    <name>SoundConfigurationUiHandler</name>
    <message>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
</context>
<context>
    <name>SoundMuteAction</name>
    <message>
        <source>Play Sounds</source>
        <translation>Reproducir Sonidos</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/sound/translations/sound_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Sound theme</source>
        <translation>Tema de sonido</translation>
    </message>
    <message>
        <source>Sound paths</source>
        <translation>Rutas de Sonidos</translation>
    </message>
    <message>
        <source>Test sound playing</source>
        <translation>Sonido de prueba</translation>
    </message>
    <message>
        <source>Play a sound</source>
        <translation>Reproducir un sonido</translation>
    </message>
    <message>
        <source>Enable sound notifications</source>
        <translation>Activar notificaciones de sonido</translation>
    </message>
</context>
<context>
    <name>SoundBuddyConfigurationWidget</name>
    <message>
        <source>Use custom sound</source>
        <translation>Usar sonido personalizado</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
</context>
<context>
    <name>SoundChatConfigurationWidget</name>
    <message>
        <source>Sound</source>
        <translation>Sonido</translation>
    </message>
    <message>
        <source>Use custom sound</source>
        <translation>Usar sonido personalizado</translation>
    </message>
</context>
<context>
    <name>SoundConfigurationUiHandler</name>
    <message>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
</context>
<context>
    <name>SoundMuteAction</name>
    <message>
        <source>Play Sounds</source>
        <translation>Reproducir Sonidos</translation>
    </message>
</context>
</TS>
